==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/InferenceContainerPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.InferenceContainerPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property livenessRoute The route to check the liveness of the inference server container.
 * @property readinessRoute The route to check the readiness of the inference server container.
 * @property scoringRoute The port to send the scoring requests to, within the inference server container.
 */
public data class InferenceContainerPropertiesArgs(
    public val livenessRoute: Output<RouteArgs>? = null,
    public val readinessRoute: Output<RouteArgs>? = null,
    public val scoringRoute: Output<RouteArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.InferenceContainerPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.InferenceContainerPropertiesArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.InferenceContainerPropertiesArgs.builder()
            .livenessRoute(livenessRoute?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .readinessRoute(readinessRoute?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .scoringRoute(scoringRoute?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [InferenceContainerPropertiesArgs].
 */
@PulumiTagMarker
public class InferenceContainerPropertiesArgsBuilder internal constructor() {
    private var livenessRoute: Output<RouteArgs>? = null

    private var readinessRoute: Output<RouteArgs>? = null

    private var scoringRoute: Output<RouteArgs>? = null

    /**
     * @param value The route to check the liveness of the inference server container.
     */
    @JvmName("rsdkuwkhtkyoaewh")
    public suspend fun livenessRoute(`value`: Output<RouteArgs>) {
        this.livenessRoute = value
    }

    /**
     * @param value The route to check the readiness of the inference server container.
     */
    @JvmName("wgmhcrfebfrblecj")
    public suspend fun readinessRoute(`value`: Output<RouteArgs>) {
        this.readinessRoute = value
    }

    /**
     * @param value The port to send the scoring requests to, within the inference server container.
     */
    @JvmName("hflgvmbrrmbljnor")
    public suspend fun scoringRoute(`value`: Output<RouteArgs>) {
        this.scoringRoute = value
    }

    /**
     * @param value The route to check the liveness of the inference server container.
     */
    @JvmName("qmkenrqntykgbphn")
    public suspend fun livenessRoute(`value`: RouteArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.livenessRoute = mapped
    }

    /**
     * @param argument The route to check the liveness of the inference server container.
     */
    @JvmName("qnrqyeqtppfpoamj")
    public suspend fun livenessRoute(argument: suspend RouteArgsBuilder.() -> Unit) {
        val toBeMapped = RouteArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.livenessRoute = mapped
    }

    /**
     * @param value The route to check the readiness of the inference server container.
     */
    @JvmName("wkrpksxbolcemcif")
    public suspend fun readinessRoute(`value`: RouteArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.readinessRoute = mapped
    }

    /**
     * @param argument The route to check the readiness of the inference server container.
     */
    @JvmName("rmunbtrurkwfkerf")
    public suspend fun readinessRoute(argument: suspend RouteArgsBuilder.() -> Unit) {
        val toBeMapped = RouteArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.readinessRoute = mapped
    }

    /**
     * @param value The port to send the scoring requests to, within the inference server container.
     */
    @JvmName("hvviylpybqsvlevp")
    public suspend fun scoringRoute(`value`: RouteArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scoringRoute = mapped
    }

    /**
     * @param argument The port to send the scoring requests to, within the inference server container.
     */
    @JvmName("ynxasaifjjwnyjjl")
    public suspend fun scoringRoute(argument: suspend RouteArgsBuilder.() -> Unit) {
        val toBeMapped = RouteArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.scoringRoute = mapped
    }

    internal fun build(): InferenceContainerPropertiesArgs = InferenceContainerPropertiesArgs(
        livenessRoute = livenessRoute,
        readinessRoute = readinessRoute,
        scoringRoute = scoringRoute,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/InferenceContainerPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.InferenceContainerPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property livenessRoute The route to check the liveness of the inference server container.
 * @property readinessRoute The route to check the readiness of the inference server container.
 * @property scoringRoute The port to send the scoring requests to, within the inference server container.
 */
public data class InferenceContainerPropertiesArgs(
    public val livenessRoute: Output<RouteArgs>? = null,
    public val readinessRoute: Output<RouteArgs>? = null,
    public val scoringRoute: Output<RouteArgs>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.InferenceContainerPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.InferenceContainerPropertiesArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.InferenceContainerPropertiesArgs.builder()
            .livenessRoute(livenessRoute?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .readinessRoute(readinessRoute?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .scoringRoute(scoringRoute?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [InferenceContainerPropertiesArgs].
 */
@PulumiTagMarker
public class InferenceContainerPropertiesArgsBuilder internal constructor() {
    private var livenessRoute: Output<RouteArgs>? = null

    private var readinessRoute: Output<RouteArgs>? = null

    private var scoringRoute: Output<RouteArgs>? = null

    /**
     * @param value The route to check the liveness of the inference server container.
     */
    @JvmName("hochxnxdelfooplr")
    public suspend fun livenessRoute(`value`: Output<RouteArgs>) {
        this.livenessRoute = value
    }

    /**
     * @param value The route to check the readiness of the inference server container.
     */
    @JvmName("nprpfdxqkqdddill")
    public suspend fun readinessRoute(`value`: Output<RouteArgs>) {
        this.readinessRoute = value
    }

    /**
     * @param value The port to send the scoring requests to, within the inference server container.
     */
    @JvmName("ixxtpxlskwqxwylx")
    public suspend fun scoringRoute(`value`: Output<RouteArgs>) {
        this.scoringRoute = value
    }

    /**
     * @param value The route to check the liveness of the inference server container.
     */
    @JvmName("xjdrarqbkuccowpv")
    public suspend fun livenessRoute(`value`: RouteArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.livenessRoute = mapped
    }

    /**
     * @param argument The route to check the liveness of the inference server container.
     */
    @JvmName("mharwbtgnyhfgtxt")
    public suspend fun livenessRoute(argument: suspend RouteArgsBuilder.() -> Unit) {
        val toBeMapped = RouteArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.livenessRoute = mapped
    }

    /**
     * @param value The route to check the readiness of the inference server container.
     */
    @JvmName("ncemgnwelodkjlbd")
    public suspend fun readinessRoute(`value`: RouteArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.readinessRoute = mapped
    }

    /**
     * @param argument The route to check the readiness of the inference server container.
     */
    @JvmName("daihfdlxhykrbuuv")
    public suspend fun readinessRoute(argument: suspend RouteArgsBuilder.() -> Unit) {
        val toBeMapped = RouteArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.readinessRoute = mapped
    }

    /**
     * @param value The port to send the scoring requests to, within the inference server container.
     */
    @JvmName("wamfhhghvojfufyl")
    public suspend fun scoringRoute(`value`: RouteArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scoringRoute = mapped
    }

    /**
     * @param argument The port to send the scoring requests to, within the inference server container.
     */
    @JvmName("dutqpdqmwwwobqjp")
    public suspend fun scoringRoute(argument: suspend RouteArgsBuilder.() -> Unit) {
        val toBeMapped = RouteArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.scoringRoute = mapped
    }

    internal fun build(): InferenceContainerPropertiesArgs = InferenceContainerPropertiesArgs(
        livenessRoute = livenessRoute,
        readinessRoute = readinessRoute,
        scoringRoute = scoringRoute,
    )
}
